# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pubs', 'pubs.plugs.extract']

package_data = \
{'': ['*']}

install_requires = \
['levenshtein>=0.20.8,<0.21.0', 'pymupdf>=1.21.1,<2.0.0']

setup_kwargs = {
    'name': 'pubs-extract',
    'version': '0.2.0',
    'description': 'A pdf annotation extraction plugin for pubs bibliography manager',
    'long_description': '# pubs-extract\n\n[![status-badge](https://ci.martyoeh.me/api/badges/Marty/pubs-extract/status.svg)](https://ci.martyoeh.me/Marty/pubs-extract)\n\nQuickly extract annotations from your pdf files with the help of the pubs bibliography manager.\nEasily organize your highlights and thoughts next to your documents.\n\n## Installation:\n\nYou can install from pypi with `pip install pubs-extract`.\n\nOr you install manually by moving the `extract` directory into your pubs `plugs` directory,\nso that the hierarchy is `pubs/plugs/extract/`\n\nThen add `extract` to your plugin list in the pubs configuration file:\n\n```ini\n[plugins]\nactive = extract\n```\n\nTo check if everything is working you can do `pubs --help` which should show you the new extract command.\nYou will be set up with the default options but if you want to change anything, read on in configuration below.\n\n> **Note**\n> This plugin is in fairly early development. It does what I need it to do, but if you have a meticulously organized library *please* make backups before doing any operation on your notes, or make use of the pubs-included git plugin.\n\n## Configuration:\n\nIn your pubs configuration file:\n\n```ini\n[plugins]\nactive = extract\n\n[[extract]]\non_import = False\nshort_header = False\nminimum_text_similarity = 0.75\nminimum_color_similarity = 0.833\nformatting = "{%quote_container> {quote} %}[{page}]{%note_container{newline}Note: {note} %}{%tag_container #{tag}%}"\n```\n\nIf `on_import` is `True` extraction is automatically run whenever a new document is added to the library,\nif false extraction has to be handled manually.\n\n---\n\n`short_header` determines if the headline of each annotation output (displaying the paper it is from) should contain the whole formatted author, year, title string (`False`) or just the citekey (`True`).\n\n---\n\n`minimum_text_similarity` sets the required similarity of an annotation\'s note and written words to be viewed\nas one. Any annotation that has both and is *under* the minimum similarity will be added in the following form:\n\n```markdown\n> [13] my annotation\nNote: my additional thoughts\n```\n\nThat is, the extractor detects additional written words by whoever annotated and adds them to the extraction.\nThe option generally should not take too much tuning, but it is there if you need it.\n\n---\n\n`minimum_color_similarity` sets the required similarity of highlight/annotation colors to be recognized as the \'pure\' versions of themselves for color mapping (see below). With a low required similarity, for example dark green and light green will both be recognized simply as \'green\' while a high similarity will not match them, instead only matching closer matches to a pure (0, 255, 0) green value.\n\nThis should generally be an alright default but is here to be changed for example if you work with a lot of different annotation colors (where dark purple and light purple get different meanings) and get false positives.\n\n---\n\nThe plugin contains a configuration sub-category of `tags`: Here, you can define meaning for your highlight/annotation colors. For example, if you always highlight the main arguments and findings in orange and always highlight things you have to follow up on in blue, you can assign the meanings \'important\' and \'todo\' to them respectively as follows:\n\n```ini\n[[[tags]]]\norange = "important"\nblue = "todo"\n```\n\nCurrently recognized colors are: `red` `green` `blue` `yellow` `purple` `orange`.\nSince these meanings are often highly dependent on personal organization and reading systems,\nno defaults are set here.\n\n---\n\n`formatting` takes a string with a variety of template options. You can use any of the following:\n\n- `{page}`: The page number the annotation was found on.\n- `{quote}`: The actual quoted string (i.e. highlighted).\n- `{note}`: The annotation note (i.e. addded reader).\n- `{%quote_container [other text] %}`: Mark the area that contains a quotation. Useful to get rid of prefixes or suffixes if no quotation exists. Usually contains some plain text and a `{quote}` element. Can *not* be nested with other containers.\n- `{%note_container [other text] %}`: Mark the area that contains a note. Useful to get rid of prefixes or suffixes if no note exists. Usually contains some plain text and a `{note}` element. Can *not* be nested with other containers.\n- `{%tag_container [other text] %}`: Mark the area that contains a tag. Useful to get rid of prefixes or suffixes if no tag exists. Usually contains some plain text and a `{tag}` element. Can *not* be nested with other containers.\n- `{newline}`: Add a line break in the resulting annotation display.\n\nFor example, the default formatting string `"{%quote_container> {quote} %}[{page}]{%note_container{newline}Note: {note} %}{%tag_container #{tag}%}"` will result in this output:\n\n```\n> Mobilizing the TPSN scheme (see above) and drawing on cultural political economy and critical governance studies, this landmark article offers an alternative account [5]\nNote: a really intersting take on polydolywhopp\n```\n\nContainer marks are useful to encapsulate a specific type of the annotation, so extracted annotations in the end don\'t contains useless linebreaks or quotations markup.\n\n## Usage:\n\n`pubs extract [-h|-w|-e] <citekeys>`\n\nFor example, to extract annotations from two entries, do:\n\n```bash\npubs extract Bayat2015 Peck2004\n```\n\nThis will print the extracted annotations to the commandline through stdout.\n\nIf you invoke the command with the `-w` option, it will write it into your notes instead:\n\n```bash\npubs extract -w Bayat2015 Peck2004\n```\n\nWill create notes for the two entries in your pubs note directory and fill them with\nthe annotations. If a note already exists for any of the entries, it will instead append\nthe annotations to the end of it, dropping all those that it already finds in the note\n(essentially only adding new annotations to the end).\n\n**PLEASE** Be aware that so far, I spent a single afternoon coding this plugin, it\ncontains no tests and operates on your notes. In my use nothing too bad happened but\nonly use it with adequate backup in place, or with your library being version controlled.\n\nYou can invoke the command with `-e` to instantly edit the notes:\n\n```bash\npubs extract -w -e Bayat2015 Peck2004\n```\n\nWill create/append annotations and drop you into the Bayat2015 note, when you close it\ndirectly into the Peck2004 note. Take care that it will be fairly annoying if you use this\noption with hundreds of entries being annotated.\n\nTo extract the annotations for all your existing entries in one go, you can use:\n\n```bash\npubs extract -w $(pubs list -k)\n```\n\nHowever, the warning for your notes\' safety goes doubly for this command since it will touch\n*most* or *all* of your notes, depending on how many entries in your library have pdfs attached.\n\nThis readme is still a bit messy, feel free to extend it and raise a PR if you have the time.\n\nWhat follows is a not-very-sorted train of though on where the plugin is at and where I\ncould see myself taking it one day, provided I find the time.\nPull requests tackling one of these areas of course very welcome.\n\n## Issues\n\nA note on the extraction: Highlights in pdfs can be somewhat difficult to parse\n(as are most things in them). Sometimes they contain the selected text that is written on the\npage, sometimes they contain the annotators thoughts as a note, sometimes they contain nothing.\nThis plugin makes an effort to find the right combination and extract the written words,\nas well as any additional notes made - but things *will* slip through or extract weirdly every now\nand again.\n\nThe easiest extraction is provided if your program writes the selection itself into the highlight\ncontent, because then we can just use that. It is harder to parse if it does not and will sometimes\nget additional words in front or behind (especially if the highlight ends in the middle of a line)\nor even cut a few off.\n\nI am not sure if there is much I can do about this.\n\n---\n\nIf you spot a bug or have an idea feel free to open an issue.\\\nI might be slow to respond but will consider them all!\n\nPull requests are warmly welcomed.\\\nIf they are big changes or additions let\'s talk about them in an issue first.\n\nThanks for using my software ❤️\n',
    'author': 'Marty Oehme',
    'author_email': 'marty.oehme@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
